==> dhist-0.1.0.crate: dhist-0.1.0/src/cli.rs <==
use clap::{
    App,
    AppSettings,
    Arg,
};

pub fn get_cli() -> clap::App<'static> {
    App::new("dhist")
        .about(clap::crate_description!())
        .author(clap::crate_authors!())
        .setting(clap::AppSettings::SubcommandRequiredElseHelp)
        // .arg(
        //     Arg::new("histfile-path")
        //         .short('H')
        //         .long("history")
        //         .about("Path to history file"),
        // )
        .subcommand(App::new(Mode::Query).about("Print history"))
        .subcommand(
            App::new(Mode::Sort).about("Sort input by history frequency"),
        )
        .subcommand(
            App::new(Mode::Increment).about("Increase usage of input by 1"),
        )
        .subcommand(
            App::new(Mode::Wrap)
                .about("Wrap a command to sort before and increment after")
                .setting(AppSettings::ArgRequiredElseHelp)
                .arg(
                    Arg::new("command")
                        .required(true)
                        .multiple_values(true)
                        .last(true),
                ),
        )
}

pub enum Mode {
    Query,
    Sort,
    Increment,
    Wrap,
}

impl From<Mode> for String {
    fn from(val: Mode) -> Self {
        match val {
            Mode::Query => "query".to_string(),
            Mode::Sort => "sort".to_string(),
            Mode::Increment => "increment".to_string(),
            Mode::Wrap => "wrap".to_string(),
        }
    }
}

impl From<&str> for Mode {
    fn from(val: &str) -> Self {
        match val {
            "query" => Mode::Query,
            "sort" => Mode::Sort,
            "increment" => Mode::Increment,
            "wrap" => Mode::Wrap,
            _ => unreachable!(),
        }
    }
}

==> dhist-0.1.1.crate: dhist-0.1.1/src/cli.rs <==
use clap::{
    Command,
    Arg,
};

pub fn get_cli() -> clap::Command<'static> {
    Command::new("dhist")
        .about(clap::crate_description!())
        .author(clap::crate_authors!())
        .arg_required_else_help(true)
        // .arg(
        //     Arg::new("histfile-path")
        //         .short('H')
        //         .long("history")
        //         .about("Path to history file"),
        // )
        .subcommand(Command::new(Mode::Query).about("Print history"))
        .subcommand(
            Command::new(Mode::Sort).about("Sort input by history frequency"),
        )
        .subcommand(
            Command::new(Mode::Increment).about("Increase usage of input by 1"),
        )
        .subcommand(
            Command::new(Mode::Wrap)
                .about("Wrap a command to sort before and increment after")
                .arg_required_else_help(true)
                .arg(
                    Arg::new("command")
                        .required(true)
                        .multiple_values(true)
                        .last(true),
                ),
        )
}

pub enum Mode {
    Query,
    Sort,
    Increment,
    Wrap,
}

impl From<Mode> for String {
    fn from(val: Mode) -> Self {
        match val {
            Mode::Query => "query".to_string(),
            Mode::Sort => "sort".to_string(),
            Mode::Increment => "increment".to_string(),
            Mode::Wrap => "wrap".to_string(),
        }
    }
}

impl From<&str> for Mode {
    fn from(val: &str) -> Self {
        match val {
            "query" => Mode::Query,
            "sort" => Mode::Sort,
            "increment" => Mode::Increment,
            "wrap" => Mode::Wrap,
            _ => unreachable!(),
        }
    }
}
